@@ -150,16 +150,15 @@ class MHL(object):  # pylint:disable=too-few-public-methods
         self.path = path
         self.lockfile = lockfile
         self.verbose = verbose
-        self.mhlfile = MHLFile(self, path, lockfile, people, verbose=self.verbose)
+        self.mhlfile = MHLFile(path, lockfile, people, verbose=self.verbose)
 
 
 class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     """MHL class."""
 
     # pylint:disable=too-many-public-methods,too-many-arguments
-    def __init__(self, mhl, path, lockfile, people, verbose=False):
+    def __init__(self, path, lockfile, people=None, verbose=False):
         """Initialize the object."""
-        self.mhl = mhl
         self.path = path
         self.people = people
         self.lockfile = lockfile
@@ -234,6 +233,9 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
             if entry.type != 'host':
                 continue
 
+            if line.is_failover:
+                continue
+
             # check hostname
             if hostname not in self.hostnames:
                 self.hostnames[hostname] = line
@@ -586,8 +588,8 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
 
     def readlines(self):
         """Read in the lines of the MHL file."""
-        mhlfile = open(self.path, 'r')
-        return mhlfile.readlines()
+        with open(self.path, "r") as mhlfile:
+            return mhlfile.readlines()
 
     def update_file(self):
         """Update the production instance of the MHL file."""
@@ -617,35 +619,35 @@ class MHLFile(object):  # pylint:disable=too-many-instance-attributes
     def writelines(self, filename):
         """Write out the MHL file to disk."""
         # write out a new copy of the mhl to disk
-        outputfile = open(filename, 'w')
-        lines = []
-        for line in self.lines:
-            lines.append('%s\n' % (line.line))
-        outputfile.writelines(lines)
+        with open(filename, "w") as outputfile:
+            lines = []
+            for line in self.lines:
+                lines.append('%s\n' % (line.line))
+            outputfile.writelines(lines)
 
     def writemissing(self, filename):
         """Write out the MHL file to disk including missing IPs."""
         # write out a new copy of the mhl to disk
-        outputfile = open(filename, 'w')
-        lines = []
+        with open(filename, "w") as outputfile:
+            lines = []
 
-        missing_ips = sorted(self.missing_ips)
+            missing_ips = sorted(self.missing_ips)
 
-        last_ip = None
+            last_ip = None
 
-        for line in self.lines:
-            ipaddr = None
-            if line.entry and line.entry.ip:
-                ipaddr = netaddr.IPAddress(line.entry.ip)
+            for line in self.lines:
+                ipaddr = None
+                if line.entry and line.entry.ip:
+                    ipaddr = netaddr.IPAddress(line.entry.ip)
 
-            if not last_ip:
-                last_ip = ipaddr
+                if not last_ip:
+                    last_ip = ipaddr
 
-            while ipaddr and missing_ips and ipaddr > missing_ips[0]:
-                lines.append('#%s\n' % (missing_ips.pop(0)))
+                while ipaddr and missing_ips and ipaddr > missing_ips[0]:
+                    lines.append('#%s\n' % (missing_ips.pop(0)))
 
-            lines.append('%s\n' % (line.line))
-        outputfile.writelines(lines)
+                lines.append('%s\n' % (line.line))
+            outputfile.writelines(lines)
 
 
 class MHLLine(object):
@@ -677,6 +679,7 @@ class MHLLine(object):
         # blanks and comments
         self.is_blank = False
         self.is_comment = False
+        self.is_failover = False
 
         # check if line is blank
         if not line.strip():
@@ -691,6 +694,11 @@ class MHLLine(object):
         # set entry
         self.entry = self.get_entry()
 
+        # Check for failover status
+        if self.is_comment:
+            if "failover" in getattr(self.entry, "tags", []):
+                self.is_failover = True
+
     def check_ip(self, ipaddr):
         """Check an IP address for validity."""
         errors = []
